/*
 * (C)(P)2003 Mart Karu, TPU, <karu@metal.ee>
 *
 * User: karu
 * Date: Apr 22, 2003
 * Time: 12:05:21 AM
 */

import javax.sound.sampled.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;

public class HeliJupp extends JPanel implements MouseListener, MouseMotionListener
{
	private int heliPikkus = 200;
	private final Color taustaVarv = Color.WHITE;
	private final Color aktiivseTaustaVarv = new Color( 255, 255, 204 );

	private int klikitiX;

	private byte[] soundiBitid = null;
	private AudioFormat formaat = null;

	private String jupiNimi = "";
	private PlayerThread player = null;

	public HeliJupp( File file )
	{
		this.jupiNimi = file.getName();
		initsialiseeri();
		loeFailist( file );
		if ( soundiBitid != null )
		{
			System.out.println( soundiBitid.length );
			this.heliPikkus = soundiBitid.length;
		}
	}

	private void initsialiseeri()
	{
		setBackground( taustaVarv );
		setVisible( true );

		this.addMouseListener( this );
		this.addMouseMotionListener( this );
	}

	public int getHeliPikkus()
	{
		return heliPikkus;
	}

	public void paint( Graphics g )
	{
		super.paint( g );
		g.drawString( this.jupiNimi, 5, ( ( getHeight() + g.getFont().getSize() ) / 2 ) );
	}

	public void mouseClicked( MouseEvent e )
	{
		if ( e.getClickCount() == 2 )
		{
			JFileChooser fc = new JFileChooser();
			int result = fc.showOpenDialog( this );
			if ( result == JFileChooser.APPROVE_OPTION )
			{
				loeFailist( fc.getSelectedFile() );
			}
		}
	}

	private void loeFailist( File file )
	{
		try
		{
			AudioInputStream sisse = null;
			sisse = AudioSystem.getAudioInputStream( file );
			formaat = sisse.getFormat();
			System.out.println( "sample:" + formaat.getSampleRate() );
			System.out.println( "framer:" + formaat.getFrameRate() );
			System.out.println( "framesize:" + formaat.getFrameSize() );
			System.out.println( "sizeinbits:" + formaat.getSampleSizeInBits() );
			System.out.println( "size: " + formaat.getFrameRate() * formaat.getFrameSize() );
			ByteArrayOutputStream malu = new ByteArrayOutputStream();
			DataInputStream dis = new DataInputStream( sisse );
			int nr = dis.readInt();
			while ( nr != -1 )
			{
				malu.write( nr );
				nr = sisse.read();
			}
			soundiBitid = malu.toByteArray();

		}
		catch ( UnsupportedAudioFileException e1 )
		{
			e1.printStackTrace();
		}
		catch ( IOException e1 )
		{
			e1.printStackTrace();
		}
	}

	public void mouseEntered( MouseEvent e )
	{
		setBackground( aktiivseTaustaVarv );
		repaint();
	}

	public void mouseExited( MouseEvent e )
	{
		setBackground( taustaVarv );
		seisataHeli();
		repaint();
	}

	public void mousePressed( MouseEvent e )
	{
		klikitiX = e.getX();
		mangiHeli();
	}

	public void mouseReleased( MouseEvent e )
	{
		seisataHeli();
	}

	public void mouseDragged( MouseEvent e )
	{
		{
			int newPos = ( ( int ) this.getLocation().getX() - klikitiX ) + e.getX();
			newPos = newPos < 0 ? 0 : newPos;
			this.setLocation( newPos, ( int ) this.getLocation().getY() );
		}
	}

	public void mouseMoved( MouseEvent e )
	{
	}

	public void mangiHeli()
	{
		if ( soundiBitid == null ) return;
		if ( soundiBitid.length == 0 ) return;
		if ( player != null ) seisataHeli();
		player = new PlayerThread( soundiBitid, formaat );
		player.start();
	}

	private void seisataHeli()
	{
		if ( player != null )
		{
			player.stopThread();
			player = null;
		}
	}

}
